************************************************
* This file uses ngraf008.dta and creates an   *
* individual-level data file for 1990.         *
************************************************

**************************************************************************
* SAMPLE: Use only couples in which both partners are between the ages of*
* 20-34                                                                  *
**************************************************************************


clear
macro drop _all
program drop _all
set more off
set linesize 80

capture log close
log using "/project/graf_schwartz/demresearch/public/individual_1990.log",replace

set mem 1500m



use "/project/graf_schwartz/demresearch/public/ngraf008.dta"





************************************
** RELATIONSHIP TYPE DUMMIES      **
************************************

gen ss_female = (samesex == 1 & sex == 2)
gen ss_male = (samesex == 1 & sex == 1)
gen os_cohab = (cohab == 1)
gen os_married = (spous == 1)


******************************************
**SINGLE RELATIONSHIP TYPE INDICATOR VAR**
******************************************

gen     rel_var = 1 if os_married == 1
replace rel_var = 2 if os_cohab   == 1
replace rel_var = 3 if ss_female  == 1
replace rel_var = 4 if ss_male    == 1

lab def rel_var 1 "1:os_married" 2 "2:os_cohab" 3 "3:ss_female" 4 "4:ss_male"
lab val rel_var rel_var


************************************
* Opposite sex vs. same sex couple *
************************************

gen os = (os_married == 1 | os_cohab == 1)


************************************
* Geographic mobility              *
************************************

gen geog_mob = (bpl ~= statefip)



***************************
* Race/ethnicity variable *
***************************

tab hispan, miss
tab hispan, miss nolab

* 0 = not hispanic, else hispanic, no missing values

gen hispan_recode = (hispan ~= 0)


* check

tab hispan hispan_recode, miss


tab race, miss
tab race, miss nolab

* 1 = white, 2 = black, 3-9 = other
* Putting those of 2 or more races as other. Check sensitivity.


gen     race_recode = 1 if race == 1
replace race_recode = 2 if race == 2
replace race_recode = 3 if race >= 3 & race <= 9


* check

tab race race_recode, miss

* Create composite race/ethnicity variable.
* 1 = white non-hispanic
* 2 = black non-hispanic
* 3 = hispanic
* 4 = other


gen     re = 1 if race_recode == 1 & hispan_recod == 0
replace re = 2 if race_recode == 2 & hispan_recod == 0
replace re = 3 if                    hispan_recod == 1
replace re = 4 if race_recode == 3 & hispan_recod == 0

lab def re 1 "1:white non-h" 2 "2:black non-h" 3 "3:Hispanic" 4 "4:Other"
lab val re re

tab re



***************************************
* Market conditions var - by metarea  *
***************************************


*(1) number of people by type of relationship

sort serial R

bysort metarea: egen xnum_ss_fem = sum(perwt) if ss_female == 1
bysort metarea: egen xnum_ss_male = sum(perwt) if ss_male == 1
bysort metarea: egen xnum_ss = sum(perwt) if samesex == 1


* variables on every record:
*    number of individuals in co-resident same-sex couples
*     by  metarea

bysort metarea: egen num_ss_fem = mean(xnum_ss_fem)
bysort metarea: egen num_ss_male = mean(xnum_ss_male)
bysort metarea: egen num_ss = mean(xnum_ss)
replace num_ss_fem = 0 if num_ss_fem ==.
replace num_ss_male = 0 if num_ss_male ==.
replace num_ss = 0 if num_ss ==.

drop xnum*

* total number of individuals in co-resident same-sex couples

egen xtnum_ss_fem = sum(perwt) if ss_female == 1
egen xtnum_ss_male = sum(perwt) if ss_male == 1
egen xtnum_ss = sum(perwt) if samesex == 1

egen tnum_ss_fem = mean(xtnum_ss_fem)
egen tnum_ss_male = mean(xtnum_ss_male)
egen tnum_ss = mean(xtnum_ss)

tab tnum_ss_fem
tab tnum_ss_male
tab tnum_ss

drop xtnum*

*Number of individuals in co-resident same-sex couples who are white in metropolitan areas
bysort metarea: egen xnum_ss_fem_white = sum(perwt) if ss_female == 1 & re == 1
bysort metarea: egen xnum_ss_male_white = sum(perwt) if ss_male == 1 & re == 1
bysort metarea: egen xnum_het_white = sum(perwt) if samesex == 0 & re == 1

bysort metarea: egen num_ss_fem_white = mean(xnum_ss_fem_white)
bysort metarea: egen num_ss_male_white = mean(xnum_ss_male_white)
bysort metarea: egen num_het_white = mean(xnum_het_white)
replace num_ss_fem_white = 0 if num_ss_fem_white ==.
replace num_ss_male_white = 0 if num_ss_male_white ==.
replace num_het_white = 0 if num_het_white ==.



*(2) number of gay men and lesbians:
*      divide the number of individuals in co-resident same-sex couples
*      by partnership rate (Black et al. 2000)

 gen num_gay = num_ss_male / .284
 gen num_les = num_ss_fem / .441

*(3) number of adults by sex

 bysort metarea: egen xnum_male = sum(perwt) if sex == 1
 bysort metarea: egen xnum_fem  = sum(perwt) if sex == 2
 bysort metarea: egen  num_male = mean(xnum_male)
 bysort metarea: egen  num_fem  = mean(xnum_fem)

 gen num_het_male = num_male - num_gay
 gen num_het_fem  = num_fem  - num_les


*(4) measure of market conditions

gen cgay = num_ss_male/metpopwt
gen cles = num_ss_fem/metpopwt
gen chetero_men = num_het_male/metpopwt
gen chetero_women = num_het_fem/metpopwt
*gen chetero = (num_hetero_men + num_hetero_women)/metpopwt
*gen cwhite_re = xwhitenh_pop/metpopwt
*gen cwhite_ss_fem = xnum_ss_fem_white/num_ss_female
*gen cwhite_ss_male= xnum_ss_male_white/num_ss_male
*gen cwhite_het = xnum_het_white/num_hetero


**********************************
* Reproduce Black et al. Table 4 *
**********************************

* Percentage of gay/lesbian metarea sample (co-resident with same-sex partner)
*   in a given metarea

*table metarea, c(mean pct_gsamp mean xnum_ss_male)
*table metarea, c(mean pct_lsamp mean xnum_ss_fem)




******************************
* MAKE VARS FOR DESCRIPTIVES *
******************************


#delimit ;
keep ss_female ss_male os_cohab os_married educrec R serial cgay cles metpopwt statefip
     metarea re age rel_var os geog_mob perwt qmarst sex hhwt num_ss* num_gay num_les num_het* chet*
     ;
#delimit cr


**CATEGORICAL ED VAR***

gen     educ = 1 if educrec <  7  /*hs drop outs*/
replace educ = 2 if educrec == 7  /*hs grads*/
replace educ = 3 if educrec == 8  /*some coll*/
replace educ = 4 if educrec == 9  /*college plus*/

tab educrec educ, miss



**ASSIGN YEARS OF SCHOOLING TO ED VAR**

 gen     educ_l = 10 if educ == 1
 replace educ_l = 12 if educ == 2
 replace educ_l = 14 if educ == 3
 replace educ_l = 17 if educ == 4

tab educrec educ_l, miss

drop educrec


***AGE CATEGORIES***

   gen     agec = 1 if age >= 20 & age < 25
   replace agec = 2 if age >= 25 & age < 30
   replace agec = 3 if age >= 30 & age < 35
   replace agec = 4 if age >= 35 & age < 40
   replace agec = 5 if age >= 40 & age < 45
   replace agec = 6 if age >= 45 & age < 50
   replace agec = 7 if age >= 50 & age < 55
   replace agec = 8 if age >= 55 & age < 60
   replace agec = 9 if age >= 60 & age <=65



********
* SAVE *
********


save "/project/graf_schwartz/demresearch/public/individual_1990.dta", replace



log close




